@@ -17,4 +17,18 @@
 ======================== END OF LICENSE NOTICE ========================
   Primary Author: Anand Tiwari
 """
-__version__ = '3.1.7'
\ No newline at end of file
+from datetime import datetime
+
+
+__title__ = 'archerysec-cli'
+__authors__ = 'Anand Tiwari'
+__copyright__ = f'Copyright {datetime.now().year} Anand Tiwari, ArcherySec'
+__version__ = '3.1.8'
+__version_info__ = tuple(int(i) for i in __version__.split('.'))
+__all__ = [
+    '__title__',
+    '__authors__',
+    '__copyright__',
+    '__version__',
+    '__version_info__',
+]
\ No newline at end of file
